summaryrefslogtreecommitdiffstats
path: root/media/base/pipeline.h
diff options
context:
space:
mode:
authorscherkus@chromium.org <scherkus@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2013-12-20 21:33:30 +0000
committerscherkus@chromium.org <scherkus@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2013-12-20 21:33:30 +0000
commit58730fdf770e434b854ecfbfe1397d16109a9204 (patch)
treecbfb7808e880445201ea49aeae07c5df61308e14 /media/base/pipeline.h
parentab7d077c878a232e3a9e9240e57de8f111a8ee09 (diff)
downloadchromium_src-58730fdf770e434b854ecfbfe1397d16109a9204.zip
chromium_src-58730fdf770e434b854ecfbfe1397d16109a9204.tar.gz
chromium_src-58730fdf770e434b854ecfbfe1397d16109a9204.tar.bz2
Replace MessageLoopProxy with SingleThreadTaskRunner for media/base/.
BUG=315922 R=xhwang@chromium.org Review URL: https://codereview.chromium.org/64033005 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@242180 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'media/base/pipeline.h')
-rw-r--r--media/base/pipeline.h22
1 files changed, 11 insertions, 11 deletions
diff --git a/media/base/pipeline.h b/media/base/pipeline.h
index 222091f..bb91d29 100644
--- a/media/base/pipeline.h
+++ b/media/base/pipeline.h
@@ -21,7 +21,7 @@
#include "ui/gfx/size.h"
namespace base {
-class MessageLoopProxy;
+class SingleThreadTaskRunner;
class TimeDelta;
}
@@ -35,7 +35,7 @@ class TextTrackConfig;
class VideoRenderer;
// Pipeline runs the media pipeline. Filters are created and called on the
// message loop injected into this object. Pipeline works like a state
// machine to perform asynchronous initialization, pausing, seeking and playing.
//
// Here's a state diagram that describes the lifetime of this object.
@@ -82,8 +82,8 @@ class MEDIA_EXPORT Pipeline : public DemuxerHost {
typedef base::Callback<void(BufferingState)> BufferingStateCB;
- // Constructs a media pipeline that will execute on |message_loop|.
- Pipeline(const scoped_refptr<base::MessageLoopProxy>& message_loop,
+ // Constructs a media pipeline that will execute on |task_runner|.
+ Pipeline(const scoped_refptr<base::SingleThreadTaskRunner>& task_runner,
MediaLog* media_log);
virtual ~Pipeline();
@@ -264,8 +264,8 @@ class MEDIA_EXPORT Pipeline : public DemuxerHost {
void OnVideoTimeUpdate(base::TimeDelta max_time);
// The following "task" methods correspond to the public methods, but these
// methods are run as the result of posting a task to the PipelineInternal's
// message loop.
void StartTask(scoped_ptr<FilterCollection> filter_collection,
const base::Closure& ended_cb,
const PipelineStatusCB& error_cb,
@@ -351,8 +351,8 @@ class MEDIA_EXPORT Pipeline : public DemuxerHost {
void StartClockIfWaitingForTimeUpdate_Locked();
- // Message loop used to execute pipeline tasks.
- scoped_refptr<base::MessageLoopProxy> message_loop_;
+ // Task runner used to execute pipeline tasks.
+ scoped_refptr<base::SingleThreadTaskRunner> task_runner_;
// MediaLog to which to log events.
scoped_refptr<MediaLog> media_log_;
@@ -378,12 +378,12 @@ class MEDIA_EXPORT Pipeline : public DemuxerHost {
gfx::Size natural_size_;
// Current volume level (from 0.0f to 1.0f). This value is set immediately
// via SetVolume() and a task is dispatched on the message loop to notify the
// filters.
float volume_;
// Current playback rate (>= 0.0f). This value is set immediately via
// SetPlaybackRate() and a task is dispatched on the message loop to notify
// the filters.
float playback_rate_;
@@ -414,7 +414,7 @@ class MEDIA_EXPORT Pipeline : public DemuxerHost {
bool has_video_;
// The following data members are only accessed by tasks posted to
- // |message_loop_|.
+ // |task_runner_|.
// Member that tracks the current state.
State state_;
@@ -35,7 +35,7 @@ class TextTrackConfig;
class VideoRenderer;
// Pipeline runs the media pipeline. Filters are created and called on the
-// message loop injected into this object. Pipeline works like a state
+// task runner injected into this object. Pipeline works like a state
// machine to perform asynchronous initialization, pausing, seeking and playing.
//
@@ -264,8 +264,8 @@ class MEDIA_EXPORT Pipeline : public DemuxerHost {
void OnVideoTimeUpdate(base::TimeDelta max_time);
// The following "task" methods correspond to the public methods, but these
- // methods are run as the result of posting a task to the PipelineInternal's
- // message loop.
+ // methods are run as the result of posting a task to the Pipeline's
+ // task runner.
void StartTask(scoped_ptr<FilterCollection> filter_collection,
const base::Closure& ended_cb,
@@ -378,12 +378,12 @@ class MEDIA_EXPORT Pipeline : public DemuxerHost {
gfx::Size natural_size_;
// Current volume level (from 0.0f to 1.0f). This value is set immediately
- // via SetVolume() and a task is dispatched on the message loop to notify the
+ // via SetVolume() and a task is dispatched on the task runner to notify the
// filters.
float volume_;
@@ -378,12 +378,12 @@ class MEDIA_EXPORT Pipeline : public DemuxerHost {
float volume_;
// Current playback rate (>= 0.0f). This value is set immediately via
- // SetPlaybackRate() and a task is dispatched on the message loop to notify
+ // SetPlaybackRate() and a task is dispatched on the task runner to notify
// the filters.
float playback_rate_;